Customer class

Represents the customer details returned by Paystack after a transaction.

Constructors

Customer({int? id, String? firstName, String? lastName, String? email, String? customerCode, String? phone, Map<String, dynamic>? metadata})
const
Customer.fromJson(Map<String, dynamic> json)
factory

Properties

customerCode → String?
final
email → String?
final
firstName → String?
final
fullName → String?
Returns the customer's full name, or null if both first and last name are unavailable.
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → int?
final
lastName → String?
final
metadata → Map<String, dynamic>?
final
phone → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? firstName, String? lastName, String? email, String? customerCode, String? phone, Map<String, dynamic>? metadata}) → Customer
Returns a copy of this Customer with the specified fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override