PaystackBearer enum

Defines who bears the Paystack transaction fees when using split payments.

Pass this to PayWithPayStack.now via the bearer parameter.

Inheritance
Available extensions

Values

account → const PaystackBearer

The main account bears the transaction fees (default).

const PaystackBearer('account')
subaccount → const PaystackBearer

The subaccount bears the transaction fees.

const PaystackBearer('subaccount')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw string value sent to the Paystack API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaystackBearer>
A constant List of the values in this enum, in order of their declaration.