isProcessing property
bool
get
isProcessing
Whether the batch is actively being processed by Paystack.
Implementation
bool get isProcessing => status?.toLowerCase() == 'processing';
Whether the batch is actively being processed by Paystack.
bool get isProcessing => status?.toLowerCase() == 'processing';