amount property
Price of a single unit in the major currency unit
(e.g. 15.00 for GHS 15.00). The plugin converts this to
the subunit (pesewas/kobo) automatically when building the metadata.
Implementation
final double amount;
Price of a single unit in the major currency unit
(e.g. 15.00 for GHS 15.00). The plugin converts this to
the subunit (pesewas/kobo) automatically when building the metadata.
final double amount;