imageUrl property
Optional URL for the product image. Shown on the Paystack Dashboard when viewing the transaction's metadata.
Implementation
final String? imageUrl;
Optional URL for the product image. Shown on the Paystack Dashboard when viewing the transaction's metadata.
final String? imageUrl;