Authorization class
Represents the payment authorization details returned by Paystack after a successful transaction.
Constructors
- Authorization({String? authorizationCode, String? bin, String? last4, String? expMonth, String? expYear, String? channel, String? cardType, String? bank, String? countryCode, String? brand, bool? reusable, String? signature, String? accountName, String? mobileMoneyNumber})
-
const
-
Authorization.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountName → String?
-
final
-
final
- bank → String?
-
final
- bin → String?
-
final
- brand → String?
-
final
- cardType → String?
-
final
- channel → String?
-
final
- countryCode → String?
-
final
- expMonth → String?
-
final
- expYear → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- last4 → String?
-
final
- mobileMoneyNumber → String?
-
final
- reusable → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
final
Methods
-
copyWith(
{String? authorizationCode, String? bin, String? last4, String? expMonth, String? expYear, String? channel, String? cardType, String? bank, String? countryCode, String? brand, bool? reusable, String? signature, String? accountName, String? mobileMoneyNumber}) → Authorization - Returns a copy of this Authorization with the specified fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override