PaymentData class

Represents the full payment data returned by Paystack after a transaction is verified.

Constructors

PaymentData({int? id, String? domain, String? status, String? reference, String? receiptNumber, int? amount, int? requestedAmount, String? message, String? gatewayResponse, String? paidAt, String? createdAt, String? channel, String? currency, String? ipAddress, String? orderId, int? fees, dynamic feesSplit, Authorization? authorization, Customer? customer})
const
PaymentData.fromJson(Map<String, dynamic> json)
factory

Properties

amount int?
Amount in the smallest currency unit (e.g. kobo for NGN, pesewas for GHS).
final
amountInMajorUnit double?
The amount in the major currency unit (e.g. GHS, NGN).
no setter
authorization Authorization?
final
channel String?
final
createdAt String?
final
currency String?
final
customer Customer?
final
domain String?
final
fees int?
Transaction fees, in the smallest currency unit.
final
feesInMajorUnit double?
The fees in the major currency unit.
no setter
feesSplit → dynamic
final
gatewayResponse String?
final
hashCode int
The hash code for this object.
no setteroverride
id int?
final
ipAddress String?
final
isSuccessful bool
Whether this transaction was successful.
no setter
message String?
final
orderId String?
final
paidAt String?
final
receiptNumber String?
final
reference String?
final
requestedAmount int?
Amount originally requested, in the smallest currency unit.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

copyWith({int? id, String? domain, String? status, String? reference, String? receiptNumber, int? amount, int? requestedAmount, String? message, String? gatewayResponse, String? paidAt, String? createdAt, String? channel, String? currency, String? ipAddress, String? orderId, int? fees, dynamic feesSplit, Authorization? authorization, Customer? customer}) PaymentData
Returns a copy of this PaymentData with the specified fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override