PaystackException class

A typed exception thrown by the pay_with_paystack plugin when a Paystack API request fails.

Implemented types

Constructors

PaystackException({required String message, int? statusCode, String? responseBody})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
final
responseBody String?
The raw response body returned by the Paystack API, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code returned by the Paystack API, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited